@@ -65,8 +65,6 @@ popd
 
 # libheif
 pushd $SRC/libheif
-# Ensure libvips finds heif_image_handle_get_raw_color_profile
-sed -i '/^Libs.private:/s/-lstdc++/-lc++/' libheif.pc.in
 cmake \
   -DCMAKE_BUILD_TYPE=RelWithDebInfo \
   -DCMAKE_INSTALL_PREFIX=$WORK \
@@ -177,12 +175,27 @@ cat > $WORK/lib/pkgconfig/pdfium.pc << EOF
   Cflags: -I\${includedir}
 EOF
 
+# highway
+pushd $SRC/highway
+cmake \
+  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
+  -DCMAKE_INSTALL_PREFIX=$WORK \
+  -DBUILD_SHARED_LIBS=0 \
+  -DBUILD_TESTING=0 \
+  -DHWY_ENABLE_CONTRIB=0 \
+  -DHWY_ENABLE_EXAMPLES=0 \
+  -DHWY_ENABLE_TESTS=0 \
+  .
+make -j$(nproc)
+make install
+popd
+
 # libvips
 # Disable building man pages, gettext po files, tools, and tests
 sed -i "/subdir('man')/{N;N;N;d;}" meson.build
 meson setup build --prefix=$WORK --libdir=lib --prefer-static --default-library=static \
-  -Ddeprecated=false -Dexamples=false -Dcplusplus=false -Dintrospection=false \
-  -Dmodules=disabled -Dcpp_link_args="$LDFLAGS -Wl,-rpath=\$ORIGIN/lib"
+  -Ddeprecated=false -Dexamples=false -Dcplusplus=false -Dmodules=disabled \
+  -Dcpp_link_args="$LDFLAGS -Wl,-rpath=\$ORIGIN/lib"
 ninja -C build
 ninja -C build install
 
